@@ -29,6 +29,7 @@ local io_open  = io.open
 local req_read_body = ngx.req.read_body
 local req_get_body_data = ngx.req.get_body_data
 local req_get_body_file = ngx.req.get_body_file
+local req_get_post_args = ngx.req.get_post_args
 local req_get_uri_args = ngx.req.get_uri_args
 local req_set_uri_args = ngx.req.set_uri_args
 
@@ -42,7 +43,7 @@ local function _headers(ctx)
     end
     local headers = ctx.headers
     if not headers then
-        headers = get_headers(0)
+        headers = get_headers()
         ctx.headers = headers
     end
 
@@ -150,6 +151,29 @@ function _M.set_uri_args(ctx, args)
 end
 
 
+function _M.get_post_args(ctx)
+    if not ctx then
+        ctx = ngx.ctx.api_ctx
+    end
+
+    if not ctx.req_post_args then
+        req_read_body()
+
+        -- use 0 to avoid truncated result and keep the behavior as the
+        -- same as other platforms
+        local args, err = req_get_post_args(0)
+        if not args then
+            -- do we need a way to handle huge post forms?
+            log.error("the post form is too large: ", err)
+            args = {}
+        end
+        ctx.req_post_args = args
+    end
+
+    return ctx.req_post_args
+end
+
+
 local function get_file(file_name)
     local f, err = io_open(file_name, 'r')
     if not f then
@@ -256,7 +280,6 @@ function _M.get_port(ctx)
     return tonumber(ctx.var.server_port)
 end
 
-_M.get_method = ngx.req.get_method
 
 function _M.get_http_version()
     return ngx.req.http_version()
