@@ -64,16 +64,11 @@ local type = type
 
 
 local events_list
-
-local function new_lrucache()
-    return core.lrucache.new({
-        type = "plugin",
-        invalid_stale = true,
-        ttl = helper.get_conf_token_cache_time(),
-    })
-end
-local lrucache = new_lrucache()
-
+local lrucache = core.lrucache.new({
+    type = "plugin",
+    invalid_stale = true,
+    ttl = helper.get_conf_token_cache_time(),
+})
 local shdict_name = "ext-plugin"
 local shdict = ngx.shared[shdict_name]
 
@@ -662,14 +657,17 @@ rpc_call = function (ty, conf, ctx, ...)
 end
 
 
-local function recreate_lrucache()
+local function create_lrucache()
     flush_token()
 
     if lrucache then
         core.log.warn("flush conf token lrucache")
     end
 
-    lrucache = new_lrucache()
+    lrucache = core.lrucache.new({
+        type = "plugin",
+        ttl = helper.get_conf_token_cache_time(),
+    })
 end
 
 
@@ -693,7 +691,7 @@ function _M.communicate(conf, ctx, plugin_name)
         end
 
         core.log.warn("refresh cache and try again")
-        recreate_lrucache()
+        create_lrucache()
     end
 
     core.log.error(err)
@@ -790,7 +788,7 @@ function _M.init_worker()
     )
 
     -- flush cache when runner exited
-    events.register(recreate_lrucache, events_list._source, events_list.runner_exit)
+    events.register(create_lrucache, events_list._source, events_list.runner_exit)
 
     -- note that the runner is run under the same user as the Nginx master
     if process.type() == "privileged agent" then
