@@ -14,37 +14,30 @@
 -- See the License for the specific language governing permissions and
 -- limitations under the License.
 --
-local core     = require("apisix.core")
-local json     = core.json
-local pb       = require("pb")
-local ngx      = ngx
-local pairs    = pairs
-local ipairs   = ipairs
-local string   = string
-local tonumber = tonumber
-local type     = type
+local core              = require("apisix.core")
+local proto_fake_file   = require("apisix.plugins.grpc-transcode.proto").proto_fake_file
+local json              = core.json
+local pb                = require("pb")
+local ngx               = ngx
+local string            = string
+local tonumber          = tonumber
+local type              = type
 
 
 local _M = {version = 0.1}
 
 
 function _M.find_method(protos, service, method)
-    for k, loaded in pairs(protos) do
-        if type(loaded) == 'table' then
-            local package = loaded.package
-            for _, s in ipairs(loaded.service or {}) do
-                if package .. "." .. s.name == service then
-                    for _, m in ipairs(s.method) do
-                        if m.name == method then
-                            return m
-                        end
-                    end
-                end
-            end
-        end
+    local loaded = protos[proto_fake_file]
+    if not loaded or type(loaded) ~= "table" then
+        return nil
     end
 
-    return nil
+    if not loaded.index[service] or type(loaded.index[service]) ~= "table" then
+        return nil
+    end
+
+    return loaded.index[service][method]
 end
 
 
