@@ -17,27 +17,20 @@
 local core          = require("apisix.core")
 local plugin_name   = "request-validation"
 local ngx           = ngx
-local io           = io
+local io            = io
 local req_read_body = ngx.req.read_body
 local req_get_body_data = ngx.req.get_body_data
 
 local schema = {
     type = "object",
+    properties = {
+        header_schema = {type = "object"},
+        body_schema = {type = "object"},
+        rejected_msg = {type = "string", minLength = 1, maxLength = 256}
+    },
     anyOf = {
-        {
-            title = "Body schema",
-            properties = {
-                body_schema = {type = "object"}
-            },
-            required = {"body_schema"}
-        },
-        {
-            title = "Header schema",
-            properties = {
-                header_schema = {type = "object"}
-            },
-            required = {"header_schema"}
-        }
+        {required = {"header_schema"}},
+        {required = {"body_schema"}}
     }
 }
 
@@ -75,14 +68,14 @@ function _M.check_schema(conf)
 end
 
 
-function _M.rewrite(conf, ctx)
-    local headers = core.request.headers(ctx)
+function _M.rewrite(conf)
+    local headers = ngx.req.get_headers()
 
     if conf.header_schema then
         local ok, err = core.schema.check(conf.header_schema, headers)
         if not ok then
             core.log.error("req schema validation failed", err)
-            return 400, err
+            return 400, conf.rejected_msg or err
         end
     end
 
@@ -94,41 +87,30 @@ function _M.rewrite(conf, ctx)
         if not body then
             local filename = ngx.req.get_body_file()
             if not filename then
-                return 500
+                return 500, conf.rejected_msg
             end
             local fd = io.open(filename, 'rb')
             if not fd then
-                return 500
+                return 500, conf.rejected_msg
             end
             body = fd:read('*a')
         end
 
-        local body_is_json = true
         if headers["content-type"] == "application/x-www-form-urlencoded" then
-            -- use 0 to avoid truncated result and keep the behavior as the
-            -- same as other platforms
-            req_body, error = ngx.decode_args(body, 0)
-            body_is_json = false
+            req_body, error = ngx.decode_args(body)
         else -- JSON as default
             req_body, error = core.json.decode(body)
         end
 
         if not req_body then
-            core.log.error('failed to decode the req body: ', error)
-            return 400, error
+          core.log.error('failed to decode the req body', error)
+          return 400, conf.rejected_msg or error
         end
 
         local ok, err = core.schema.check(conf.body_schema, req_body)
         if not ok then
-            core.log.error("req schema validation failed: ", err)
-            return 400, err
-        end
-
-        if body_is_json then
-            -- ensure the JSON we check is the JSON we pass to the upstream,
-            -- see https://bishopfox.com/blog/json-interoperability-vulnerabilities
-            req_body = core.json.encode(req_body)
-            ngx.req.set_body_data(req_body)
+          core.log.error("req schema validation failed", err)
+          return 400, conf.rejected_msg or err
         end
     end
 end
