@@ -22,7 +22,7 @@ local logger_socket = require("resty.logger.socket")
 local plugin_name = "syslog"
 local ngx = ngx
 local buffers = {}
-local pairs = pairs
+local ipairs   = ipairs
 local stale_timer_running = false;
 local timer_at = ngx.timer.at
 
@@ -121,7 +121,7 @@ local function remove_stale_objects(premature)
         return
     end
 
-    for key, batch in pairs(buffers) do
+    for key, batch in ipairs(buffers) do
         if #batch.entry_buffer.entries == 0 and #batch.batch_to_process == 0 then
             core.log.warn("removing batch processor stale object, conf: ",
                           core.json.delay_encode(key))
